@@ -16,6 +16,8 @@
 MLflow
 ------
 """
+import re
+import warnings
 from argparse import Namespace
 from time import time
 from typing import Any, Dict, Optional, Union
@@ -151,6 +153,13 @@ class MLFlowLogger(LightningLoggerBase):
             if isinstance(v, str):
                 log.warning(f'Discarding metric with string value {k}={v}.')
                 continue
+
+            new_k = re.sub("[^a-zA-Z0-9_/. -]+", "", k)
+            if k != new_k:
+                warnings.warn(("MLFlow only allows '_', '/', '.' and ' ' special characters in metric name.\n",
+                               f"Replacing {k} with {new_k}."))
+            k = new_k
+
             self.experiment.log_metric(self.run_id, k, v, timestamp_ms, step)
 
     @rank_zero_only
