@@ -24,7 +24,7 @@ import torch
 from torch import nn
 
 from pytorch_lightning.utilities.apply_func import apply_to_collection
-from pytorch_lightning.utilities.distributed import gather_all_tensors_if_available
+from pytorch_lightning.utilities.distributed import gather_all_tensors
 from pytorch_lightning.metrics.utils import _flatten, dim_zero_cat, dim_zero_mean, dim_zero_sum
 
 
@@ -53,21 +53,26 @@ class Metric(nn.Module, ABC):
             Forward only calls ``update()`` and returns None if this is set to False. default: True
         dist_sync_on_step:
             Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step. default: False
+            before returning the value at the step.
         process_group:
             Specify the process group on which synchronization is called. default: None (which selects the entire world)
+        dist_sync_fn:
+            Callback that performs the allgather operation on the metric state. When `None`, DDP
+            will be used to perform the allgather. default: None
     """
     def __init__(
         self,
         compute_on_step: bool = True,
         dist_sync_on_step: bool = False,
         process_group: Optional[Any] = None,
+        dist_sync_fn: Callable = None,
     ):
         super().__init__()
 
         self.dist_sync_on_step = dist_sync_on_step
         self.compute_on_step = compute_on_step
         self.process_group = process_group
+        self.dist_sync_fn = dist_sync_fn
         self._to_sync = True
 
         self.update = self._wrap_update(self.update)
@@ -76,8 +81,9 @@ class Metric(nn.Module, ABC):
         self._forward_cache = None
 
         # initialize state
-        self._reductions = {}
         self._defaults = {}
+        self._persistent = {}
+        self._reductions = {}
 
     def add_state(
         self, name: str, default, dist_reduce_fx: Optional[Union[str, Callable]] = None, persistent: bool = True
@@ -133,16 +139,10 @@ class Metric(nn.Module, ABC):
                 "`dist_reduce_fx` must be callable or one of ['mean', 'sum', 'cat', None]"
             )
 
-        if isinstance(default, torch.Tensor):
-            if LooseVersion(torch.__version__) >= LooseVersion("1.6.0"):
-                # persistent keyword is only supported in torch >= 1.6.0
-                self.register_buffer(name, default, persistent=persistent)
-            else:
-                self.register_buffer(name, default)
-        else:
-            setattr(self, name, default)
+        setattr(self, name, default)
 
         self._defaults[name] = deepcopy(default)
+        self._persistent[name] = persistent
         self._reductions[name] = dist_reduce_fx
 
     @torch.jit.unused
@@ -174,12 +174,12 @@ class Metric(nn.Module, ABC):
 
             return self._forward_cache
 
-    def _sync_dist(self):
+    def _sync_dist(self, dist_sync_fn=gather_all_tensors):
         input_dict = {attr: getattr(self, attr) for attr in self._reductions.keys()}
         output_dict = apply_to_collection(
             input_dict,
             torch.Tensor,
-            gather_all_tensors_if_available,
+            dist_sync_fn,
             group=self.process_group,
         )
 
@@ -208,12 +208,15 @@ class Metric(nn.Module, ABC):
             if self._computed is not None:
                 return self._computed
 
-            if (
-                self._to_sync
-                and torch.distributed.is_available()  # noqa: W503
-                and torch.distributed.is_initialized()  # noqa: W503
-            ):
-                self._sync_dist()
+            dist_sync_fn = self.dist_sync_fn
+            if (dist_sync_fn is None
+                    and torch.distributed.is_available()
+                    and torch.distributed.is_initialized()):
+                # User provided a bool, so we assume DDP if available
+                dist_sync_fn = gather_all_tensors
+
+            if self._to_sync and dist_sync_fn is not None:
+                self._sync_dist(dist_sync_fn)
 
             self._computed = compute(*args, **kwargs)
             self.reset()
@@ -257,3 +260,36 @@ class Metric(nn.Module, ABC):
         self.__dict__.update(state)
         self.update = self._wrap_update(self.update)
         self.compute = self._wrap_compute(self.compute)
+
+    def _apply(self, fn):
+        """ Overwrite _apply function such that we can also move metric states
+            to the correct device when `.to`, `.cuda`, etc methods are called
+        """
+        self = super()._apply(fn)
+        # Also apply fn to metric states
+        for key in self._defaults.keys():
+            current_val = getattr(self, key)
+            if isinstance(current_val, torch.Tensor):
+                setattr(self, key, fn(current_val))
+            elif isinstance(current_val, Sequence):
+                setattr(self, key, [fn(cur_v) for cur_v in current_val])
+            else:
+                raise TypeError('Expected metric state to be either a torch.Tensor'
+                                f'or a list of torch.Tensor, but encountered {current_val}')
+        return self
+
+    def persistent(self, mode: bool = True):
+        """ Method for post-init to change if metric states should be saved to
+            its state_dict
+        """
+        for key in self._persistent.keys():
+            self._persistent[key] = mode
+
+    def state_dict(self, *args, **kwargs):
+        # Register metric states to be part of the state_dict
+        state_dict = super().state_dict()
+        for key in self._defaults.keys():
+            if self._persistent[key]:
+                current_val = getattr(self, key)
+                state_dict.update({key: current_val})
+        return state_dict
